# Tensor formalism

We have a $n \in \mathbb{N}$ finite dimensional vector space $V$ such that $\dim V = n$, with a basis $\{\mathbf{e}_i\}_{i=1}^n$ and a corresponding dual space $V^*$ with a basis $\{\mathbf{\hat e}^i\}.$ In the following sections we make use of the Einstein summation convention introduced in [vector analysis](/en/physics/mathematical-physics/vector-analysis/curvilinear-coordinates/) and $\mathbb{K} = \mathbb{R} \lor\mathbb{K} = \mathbb{C}.$

## Definition

> *Definition 1*: a **tensor** is a multilinear mapping of the type 
>
> $$
>   \mathbf{T}: \underbrace{V^* \times \dots \times V^*}_p \times \underbrace{V \times \dots \times V}_q \to \mathbb{K},
> $$
>
> with $p, q \in \mathbb{N}$. Tensors are collectively denoted as 
>
> $$
>   \mathbf{T} = \underbrace{V \otimes \dots \otimes V}_p \otimes \underbrace{V^* \otimes \dots \otimes V^*}_q = \mathscr{T}_q^p(V),
> $$
>
> with $\mathscr{T}_0^0(V) = \mathbb{K}$. 

We refer to $\mathbf{T} \in \mathscr{T}_q^p(V)$ as a $(p, q)$-tensor; a mixed tensor of **contravariant rank** $p$ and **covariant rank** $q.$ It may be observed that we have $\dim \mathscr{T}_q^p (V) = n^{p+q}$ with $\dim V = n \in \mathbb{N}$.  

It follows from definition 1 and by virtue of the isomorphism between $V^{**}$ and $V$ that $\mathbf{T} \in \mathscr{T}_1^0(V) = V^*$ is a covector and $\mathbf{T} \in \mathscr{T}_0^1(V) = V$ is a vector.

## Kronecker tensor

> *Definition 2*: let $\mathbf{k} \in \mathscr{T}_1^1(V)$ be the **Kronecker tensor** be defined such that
>
> $$
>   \mathbf{k}(\mathbf{\hat e}^i, \mathbf{e}_j) = \delta^i_j,
> $$
>
> with $\delta_j^i$ the Kronecker symbol.

Let $\mathbf{\hat u} = u_i \mathbf{\hat e}^i \in V^*$ and $\mathbf{v} = v^j \mathbf{e}_j \in V$ then the tensor properties and the definition of the Kronecker tensor imply that 

$$
\begin{align*}
    \mathbf{k}(\mathbf{\hat u}, \mathbf{v}) &= \mathbf{k}(u_i \mathbf{\hat e}^i, v^j \mathbf{e}_j), \\
                                            &= u_i v^j \mathbf{k}(\mathbf{\hat e}^i, \mathbf{e}_j), \\
                                            &= u_i v^j \delta^i_j, \\
                                            &= u_i v^i. 
\end{align*}
$$

## Outer product

> *Definition 3*: the outer product $f \otimes g: X \times Y \to \mathbb{K}$ of two scalar functions $f: X \to \mathbb{K}$ and $g: Y \to \mathbb{K}$ is defined as
>
> $$
>   (f \otimes g)(x,y) = f(x) g(y),
> $$
>
> for all $(x,y) \in X \times Y$. 

The outer product is associative and distributive with respect to addition and scalar multiplication, but not commutative. 

Note that although the same symbol is used for the outer product and the denotion of a tensor space, these are not equivalent.

For the following statements we take $p=q=r=s=1$ without loss of generality.

> *Definition 4*: the mixed $(p, q)$-tensor $\mathbf{e}_i \otimes \mathbf{\hat e}^j \in \mathscr{T}_q^p(V)$ is defined as
>
> $$
>   (\mathbf{e}_i \otimes \mathbf{\hat e}^j)(\mathbf{\hat u}, \mathbf{v}) = \mathbf{k}(\mathbf{\hat u}, \mathbf{e}_i) \mathbf{k}(\mathbf{\hat e}^j, \mathbf{v}),
> $$
>
> for all $(\mathbf{\hat u}, \mathbf{v}) \in V^* \times V$. 

From this definition the subsequent theorem follows naturally. 

> *Theorem 1*: let $\mathbf{T} \in \mathscr{T}_q^p(V)$ be a tensor, then there exists **holors** $T_j^i \in \mathbb{K}$ such that
>
> $$
>   \mathbf{T} = T^i_j \mathbf{e}_i \otimes \mathbf{\hat e}^j,
> $$
>
> with $T^i_j = \mathbf{T}(\mathbf{\hat e}^i, \mathbf{e}_j)$. 

??? note "*Proof*:"

    Let $\mathbf{T} \in \mathscr{T}_q^p(V)$ such that

    $$
    \begin{align*}
        \mathbf{T}(\mathbf{\hat e}^i, \mathbf{e}_j) &= T^k_l (\mathbf{e}_k \otimes \mathbf{\hat e}^l)(\mathbf{\hat e}^i, \mathbf{e}_j), \\
        &= T^k_l \mathbf{k}(\mathbf{\hat e}^i, \mathbf{e}_k) \mathbf{k}(\mathbf{\hat e}^l,\mathbf{e}_j), \\
        &= T^k_l \delta^i_k \delta^l_j, \\
        &= T^i_j.
    \end{align*}
    $$

For $\mathbf{T} \in \mathscr{T}^0_q(V)$ it follows that there exists holors $T_i \in \mathbb{K}$ such that $\mathbf{T} = T_i \mathbf{\hat e}^i$ with $T_i = \mathbf{T}(\mathbf{e}_i)$, are referred to as the **covariant components** of $\mathbf{T}$ relative to a basis $\{\mathbf{e}_i\}$. 

For $\mathbf{T} \in \mathscr{T}^p_0(V)$ it follows that there exists holors $T^i \in \mathbb{K}$ such that $\mathbf{T} = T^i \mathbf{e}_i$ with $T^i = \mathbf{T}(\mathbf{\hat e}^i)$, are referred to as the **contravariant components** of $\mathbf{T}$ relative to a basis $\{\mathbf{e}_i\}$. 

If $\mathbf{T} \in \mathscr{T}^p_q(V)$, it follows that there exists holors $T^i_j \in \mathbb{K}$ are coined the **mixed components** of $\mathbf{T}$ relative to a basis $\{\mathbf{e}_i\}$. 

By definition tensors are basis independent. Holors are basis dependent.

> *Theorem 2*: let $\mathbf{S} \in \mathscr{T}^p_q(V)$ and $\mathbf{T} \in \mathscr{T}^r_s(V)$ be tensors with
>
> $$
>   \mathbf{S} = S^i_j \mathbf{e}_i \otimes \mathbf{\hat e}^j \quad \land \quad \mathbf{T} = T^r_s \mathbf{e}_r \otimes \mathbf{\hat e}^s, 
> $$
>
> then the outer product of $\mathbf{S}$ and $\mathbf{T}$ is given by
>
> $$
>   \mathbf{S} \otimes \mathbf{T} = S^i_j T^k_l \mathbf{e}_i \otimes \mathbf{e}_k \otimes \mathbf{\hat e}^j \otimes \mathbf{\hat e}^l,
> $$
>
> with $\mathbf{S} \otimes \mathbf{T} \in \mathscr{T}^{p+r}_{q+s}(V)$. 

??? note "*Proof*:"

    Let $\mathbf{S} \in \mathscr{T}^p_q(V)$ and $\mathbf{T} \in \mathscr{T}^r_s(V)$ with 

    $$
        \mathbf{S} = S^i_j \mathbf{e}_i \otimes \mathbf{\hat e}^j \quad \land \quad \mathbf{T} = T^r_s \mathbf{e}_r \otimes \mathbf{\hat e}^s, 
    $$

    then

    $$
    \begin{align*}
        \mathbf{S} \otimes \mathbf{T} &= S^i_j (\mathbf{e}_i \otimes \mathbf{\hat e}^j) \otimes T^r_s (\mathbf{e}_r \otimes \mathbf{\hat e}^s), \\
        &= S^i_j T^r_s \mathbf{e}_i \otimes \mathbf{e}_r \otimes \mathbf{\hat e}^j \otimes \mathbf{\hat e}^s.
    \end{align*}
    $$

    Which maps two vectors and two covectors, therefore $\mathbf{S} \otimes \mathbf{T} \in \mathscr{T}^{p+r}_{q+s}(V)$. 

We have from theorem 2 that the outer product of two tensors yields another tensor, with ranks adding up.

## Inner product

> *Definition 5*: a **pseudo inner product** on $V$ is a nondegenerate bilinear mapping $\bm{g}: V \times V \to \mathbb{K}$ which satisfies
>
> 1. for all $\mathbf{u} \in V \backslash \{\mathbf{0}\} \exists \mathbf{v} \in V: \; \bm{g}(\mathbf{u},\mathbf{v}) \neq 0$,
> 2. for all $\mathbf{u}, \mathbf{v} \in V: \; \bm{g}(\mathbf{u}, \mathbf{v}) = \overline{\bm{g}}(\mathbf{v}, \mathbf{u})$, 
> 3. for all $\mathbf{u}, \mathbf{v}, \mathbf{w} \in V$ and $\lambda, \mu \in \mathbb{K}: \;\bm{g}(\mathbf{u}, \lambda \mathbf{v} + \mu \mathbf{w}) = \lambda \bm{g}(\mathbf{u}, \mathbf{v}) + \mu \bm{g}(\mathbf{u}, \mathbf{w}).$

It may be observed that $\bm{g} \in \mathscr{T}_2^0$. Unlike the Kronecker tensor, the existance of an inner product is never implied. 

> *Definition 6*: let $G$ be the Gram matrix with its components $G \overset{\text{def}}= (g_{ij})$ defined as 
> 
> $$
>   g_{ij} = \bm{g}(\mathbf{e}_i, \mathbf{e}_j).
> $$

For $\mathbf{u} = u^i \mathbf{e}_i, \mathbf{v} = v^j \mathbf{e}_j \in V$ we then have

$$
\begin{align*}
    \bm{g}(\mathbf{u}, \mathbf{v}) &= \bm{g}(u^i \mathbf{e}_i, v^j \mathbf{e}_j), \\
                                   &= u^i v^j \bm{g}(\mathbf{e}_i, \mathbf{e}_j), \\
                                   &\overset{\text{def}}= u^i v^j g_{ij}.
\end{align*}
$$

> *Proposition 1*: the Gram matrix $G$ is symmetric and nonsingular such that
>
> $$
>   g^{ik} g_{kj} = \delta^i_j,
> $$
>
> with $G^{-1} \overset{\text{def}}= (g^{ij})$. 

??? note "*Proof*:"

    Let $G$ be the Gram matrix, symmetry of $G$ follows from defintion 5. Suppose that $G$ is singular, then there exists $\mathbf{u} = u^i \mathbf{e}_i \in V \backslash \{\mathbf{0}\}$ such that $G \mathbf{u} = \mathbf{0} \implies u^i g_{ij} = 0$, as a result we find that 

    $$
        \forall \mathbf{v} = v^j \mathbf{e}_j \in V: 0 = u^i g_{ij} v^j = u^i \bm{g}(\mathbf{e}_i, \mathbf{e}_j) v^j = \bm{g}(u^i \mathbf{e}_i, v^j \mathbf{e}_j) = \bm{g}(\mathbf{u}, \mathbf{v}),
    $$

    which contradicts the non-degeneracy of the pseudo inner product in definition 5.  

> *Theorem 3*: there exists a bijective linear map $\mathbf{g}: V \to V^*$ with inverse $\mathbf{g}^{-1}$ such that
>
> 1. $\forall \mathbf{u}, \mathbf{v} \in V: \; \bm{g}(\mathbf{u}, \mathbf{v}) = \mathbf{k}(\mathbf{g}(\mathbf{u}), \mathbf{v})$, 
> 2. $\forall \mathbf{\hat u} \in V^*, \mathbf{v} \in V: \; \bm{g}(\mathbf{g}^{-1}(\mathbf{\hat u}), \mathbf{v}) = \mathbf{k}(\mathbf{\hat u}, \mathbf{v})$,
>
> with $\mathbf{g}(\mathbf{v}) = G \mathbf{v}$ for all $\mathbf{v} \in V$. 

??? note "*Proof*:"

    Let $\mathbf{u} \in V$ and let $\mathbf{\hat u} \in V^*$, suppose $\mathbf{\hat u}: \mathbf{v} \mapsto \bm{g}(\mathbf{u}, \mathbf{v})$ then we may define $\mathbf{g}: V \to V^*: \mathbf{u} \mapsto \mathbf{g}(\mathbf{u}) \overset{\text{def}} = \mathbf{\hat u}$. 

    Let $\mathbf{v} \in V \backslash \{\mathbf{0}\}: \mathbf{g}(\mathbf{v}) = \mathbf{0}$, then

    $$
        0 = \mathbf{k}(\mathbf{g}(\mathbf{v}), \mathbf{w}) \overset{\text{def}} = \bm{g}(\mathbf{v}, \mathbf{w}),
    $$

    for all $\mathbf{w} \in V$, which contradicts the non-degeneracy of the pseude inner product in definition 5. Hence $\mathbf{g}$ is injective, since $\dim V$ is finite $\mathbf{g}$ is also bijective.

    Let $\mathbf{u} = u^i \mathbf{e}_i, \mathbf{v} = v^j \mathbf{e}_j \in V$ and define $\mathbf{g}(\mathbf{e}_i) = \text{g}_{ij} \mathbf{\hat e}^j$ such that

    $$
        \mathbf{k}(\mathbf{g}(\mathbf{u}), \mathbf{v}) \overset{\text{def}} = \bm{g}(\mathbf{u}, \mathbf{v}) = g_{ij} u^i v^j,
    $$

    but also

    $$
        \mathbf{k}(\mathbf{g}(\mathbf{u}), \mathbf{v}) = \text{g}_{ij} u^i v^k\mathbf{k}(\mathbf{\hat e}^j, \mathbf{e}_k) = \text{g}_{ij} u^i v^k \delta^j_k = \text{g}_{ij} u^i v^j. 
    $$

    Since $u^i, v^j \in \mathbb{K}$ are arbitrary it follows that $\text{g}_{ij} = g_{ij}$. 

Consequently the inverse $\mathbf{g}^{-1}: V^* \to V$ has the property $\mathbf{g}^{-1}(\mathbf{\hat u}) = G^{-1} \mathbf{\hat u}$ for all $\mathbf{\hat u} \in V^*$. The bijective linear map $\mathbf{g}$ is commonly known as the **metric** and $\mathbf{g}^{-1}$ as the **dual metric**. 

It follows from theorem 3 that for $\mathbf{u} = u^i \mathbf{e}_i \in V$ and $\mathbf{\hat u} = u_i \mathbf{\hat e}^i \in V^*$ we have

$$
    \mathbf{g}(\mathbf{u}) = g_{ij} u^i \mathbf{\hat e}^j = u_j \mathbf{\hat e}^j = \mathbf{\hat u},
$$

with $u_j = g_{ij} u^i$ and

$$
    \mathbf{g}^{-1}(\mathbf{\hat u}) = g^{ij} u_i \mathbf{e}_j = u^j \mathbf{e}_j = \mathbf{u},
$$

with $u^j = g^{ij} u_i$. 

> *Definition 7*: the basis $\{\mathbf{e}_i\}$ of $V$ induces a **reciprocal basis** $\{\mathbf{g}^{-1}(\mathbf{\hat e}^i)\}$ of $V$ given by 
> 
> $$
> \mathbf{g}^{-1}(\mathbf{\hat e}^i) = g^{ij} \mathbf{e}_j.
> $$
>
> Likewise the basis $\{\mathbf{\hat e}^i\}$ of $V^*$ induces a **reciprocal dual basis** $\{\mathbf{g}(\mathbf{e}_i)\}$ of $V^*$ given by
>
> $$
>   \mathbf{g}(\mathbf{e}^i) = g_{ij} \mathbf{\hat e}^j.
> $$

Sofar, a vector space $V$ and its associated dual space $V^*$ have been introduced as a priori independent entities. An inner product provides us with an explicit mechanism to construct a bijective linear mapping associated with each vector by virtue of the metric. 